@@ -10,6 +10,7 @@ from gerrit.accounts.accounts import GerritAccounts
 from gerrit.groups.groups import GerritGroups
 from gerrit.plugins.plugins import GerritPlugins
 from gerrit.changes.changes import GerritChanges
+from gerrit.gitiles import GerritGitiles
 
 
 class GerritClient(object):
@@ -182,6 +183,11 @@ class GerritClient(object):
         """
         return self.config.get_server_info()
 
+    @property
+    def gitiles(self):
+        """gitiles plugin rest api"""
+        return GerritGitiles(gerrit=self)
+
     def get(self, endpoint, **kwargs):
         """
         Send HTTP GET to the endpoint.
